==> camel-pulsar-2.25.2-sources.jar: org/apache/camel/component/pulsar/PulsarMessageReceiptFactory.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.pulsar;

import org.apache.camel.Exchange;
import org.apache.pulsar.client.api.Consumer;
import org.apache.pulsar.client.api.Message;

/**
 * Factory to create a new {@link PulsarMessageReceipt} to store on the {@link Exchange}.
 * <p>
 * Implement this interface if an alternate implementation of {@link PulsarMessageReceipt} is required
 * as newer Pulsar clients may have acknowledgement functionality not yet supported by {@link DefaultPulsarMessageReceipt}.
 */
public interface PulsarMessageReceiptFactory {

    /**
     * Creates a new instance of {@link PulsarMessageReceipt}.
     */
    PulsarMessageReceipt newInstance(Exchange exchange, Message message, Consumer consumer);

}

==> camel-pulsar-3.4.5-sources.jar: org/apache/camel/component/pulsar/PulsarMessageReceiptFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.pulsar;

import org.apache.camel.Exchange;
import org.apache.pulsar.client.api.Consumer;
import org.apache.pulsar.client.api.Message;

/**
 * Factory to create a new {@link PulsarMessageReceipt} to store on the
 * {@link Exchange}.
 * <p>
 * Implement this interface if an alternate implementation of
 * {@link PulsarMessageReceipt} is required as newer Pulsar clients may have
 * acknowledgement functionality not yet supported by
 * {@link DefaultPulsarMessageReceipt}.
 */
public interface PulsarMessageReceiptFactory {

    /**
     * Creates a new instance of {@link PulsarMessageReceipt}.
     */
    PulsarMessageReceipt newInstance(Exchange exchange, Message message, Consumer consumer);

}
